Learn R Programming

weatherjoin (version 0.2.2)

.map_time_columns: Multi-column time input path Map time columns to roles

Description

Multi-column time input path Map time columns to roles

Usage

.map_time_columns(time_cols, names_x)

Value

A list with mode ("ymd" or "ydoy") and role names: year, month, day, hour (optional), doy (optional).

Arguments

time_cols

Character vector of column names supplied by the user via time=.

names_x

Names of the input table.