Multi-column time input path Validate time components and build Date safely
.validate_time_components(
y,
m = NULL,
d = NULL,
doy = NULL,
h = NULL,
mode = c("ymd", "ydoy"),
time_api_resolved = c("daily", "hourly"),
time_cols = character(),
max_examples = 5L
)A list with date (Date) and hour (integer, possibly NA if missing and not allowed).
Integer-ish vectors (for mode="ymd").
Integer-ish vector (for mode="ydoy").
Optional integer-ish vector.
"ymd" or "ydoy"
"hourly" or "daily" (for hourly requirement checks)
Character vector of user-specified columns for error context.
How many bad examples to show in error messages.