powered by
Multi-column time input path Map time columns to roles
.map_time_columns(time_cols, names_x)
A list with mode ("ymd" or "ydoy") and role names: year, month, day, hour (optional), doy (optional).
mode
Character vector of column names supplied by the user via time=.
time=
Names of the input table.